Changelog
=========

.. currentmodule:: marshmallow_cbor

This library adheres to `Semantic Versioning <http://semver.org/>`_.

**0.1.0** (2021-06-15)

- Initial Release


**0.0.1** (Yanked)

- Initial Release
